from h5py import File, Group
from .metadata import Metadata


class Scatterer(Metadata):
    """
    Metadata associated to a scatterer
    """

    def __init__(self, name: str):
        """
        Parameters
        ----------
        name : str
            Name of the scatterer
        """
        self.name = name

    @staticmethod
    def from_hdf5(store: File | Group) -> "Scatterer":
        if "name" not in store.attrs.keys():
            raise ValueError("no name for a scatterer")
        name = store.attrs["name"]
        if not isinstance(name, str):
            raise ValueError(
                "name must be a string, not {}".format(type(name))
            )
        return Scatterer(name=name)

    def to_hdf5(self, store: File | Group) -> File | Group:
        store.attrs["name"] = self.name
        return store
